(:~
 : This modules handles calling the right HTML file for each selected file of the
 : edition view. It is called by book.html.
 :
 : @author Hannes Riebl
 : @author Michelle Weidling
 : @version 1.0
 :)

xquery version "3.1";

module namespace edition="http://bdn-edition.de/ns/edition";

declare namespace templates="http://exist-db.org/xquery/templates";
declare namespace xhtml="http://www.w3.org/1999/xhtml";

import module namespace config="https://sade.textgrid.de/ns/config" at "../config.xqm";

declare variable $edition:HTML-path := $config:app-root || "/resources/edition/";

(:~
 : The main function sets several parameters which are necessary for the display
 : of the text, e.g. the start and ending chapters which users can set manually
 : afterwards.
 :
 : Sample URL: http://localhost:8080/exist/apps/sade/book.html?file=12345&edition=app
 :
 : @author Hannes Riebl
 : @author Michelle Weidling
 : @param $node the HTML node with the attribute which triggered this call
 : @param $model a map containing arbitrary data - used to pass information between template calls
 : @version 1.0
 : @return a map object with data taht is important for edition:display
 :)
declare
  %templates:wrap
  function edition:main($node as node(), $model as map(*)) as map(*)
{
  map
  {
    "file": request:get-parameter("file", ""),
    "start-chapter": request:get-parameter("startChapter", "1"),
    "end-chapter": request:get-parameter("endChapter", "9999"),
    "edition": request:get-parameter("edition", "digital")
  }
};

(:~
 : Selects and displays the appropriate HTML site according to the map data that
 : has been created in edition:main.
 :
 : This function is called by bdn-utils:inject-cols.
 :
 : @author Hannes Riebl
 : @author Michelle Weidling
 : @param $node the HTML node with the attribute which triggered this call
 : @param $model a map containing arbitrary data - used to pass information between template calls
 : @version 1.0
 : @return A xhtml:div which is embedded into book.html
 :)
declare
  %templates:wrap
  function edition:display($node as node()*, $model as map(*))
  as element(xhtml:div)
{
  let $file := $model("file")
  let $mode := $model("edition")
  let $html-suffix :=
    switch ($mode)
      case "app" return
        "critical"
      case "code" return
        "code"
      case "digital" return
        "digital"
      default return
        $mode
  let $html-filename := $file || "-" || $html-suffix || ".html"
  let $doc := edition:open-file($html-filename)

  return
    $doc/xhtml:div
};


(:~
 : Selects and displays the appropriate HTML site that holds the rdg spans
 : according to the map data that has been created in edition:main.
 :
 : This function is called by bdn-utils:inject-cols.
 :
 : @author Hannes Riebl
 : @author Michelle Weidling
 : @param $node the HTML node with the attribute which triggered this call
 : @param $model a map containing arbitrary data - used to pass information between template calls
 : @version 1.0
 : @return A xhtml:div which is embedded into book.html
 :)
declare
  %templates:wrap
  function edition:display-variants-and-quotes($node as node()*, $model as map(*))
  as element(xhtml:div)
{
  let $file := $model("file")
  let $html-filename := $file || "-digital-variants-and-quotes.html"
  let $doc := edition:open-file($html-filename)

  return
    $doc/xhtml:div
};


(:~
 : Displays the foreword.
 :)
declare
  %templates:wrap
  function edition:foreword($node as node()*, $model as map(*))
  as element(xhtml:div)
{
  let $author := request:get-parameter("author", "")
  let $html-filename := $author || "-foreword.html"
  return
      doc($config:edition || $author || "/" || $html-filename)/*
};

(:~
 : Opens a given HTML file.
 :
 :)
declare function edition:open-file($html-filename as xs:string) as node()*
{
  let $first-part :=
      if (matches($html-filename, "bahrdt-semler")) then
          "bahrdt-semler"
      else
          substring-before($html-filename, "-")
    let $author :=
      if (matches($first-part, "[0-9]")) then
        false()
      else
        true()
    return
      if ($author) then
        doc($config:edition || $first-part || "/" || $html-filename)
      else
        doc($config:edition || "/single-files/" || $html-filename)
};
